@@ -53,12 +53,14 @@ void display_help(char *argv0, int exitcode)
 	fprintf(stderr, "        -h, --help		display help\n");
 	fprintf(stderr, "        -s, --span <span num>	specify the span\n");
 	fprintf(stderr, "        -l, --loopback <localhost|networkline|"\
-						"networkpayload|off>\n"\
+						"networkpayload|loopup|"\
+						"loopdown|off>\n"\
 			"\t\tlocalhost - loop back towards host\n"\
 			"\t\tnetworkline - network line loopback\n"\
 			"\t\tnetworkpayload - network payload loopback\n"\
 			"\t\tloopup - transmit loopup signal\n"\
-			"\t\tloopdown - transmit loopdown signal\n");
+			"\t\tloopdown - transmit loopdown signal\n"\
+			"\t\toff - end loopback mode\n");
 	fprintf(stderr, "        -i, --insert <fas|multi|crc|cas|prbs|bipolar>"\
 			"\n\t\tinsert an error of a specific type\n");
 	fprintf(stderr, "        -r, --reset		"\
@@ -79,7 +81,6 @@ int main(int argc, char *argv[])
 
 	int doloopback = 0;
 	char *larg = NULL;
-	int sflag = 0;
 	int span = 1;
 	int iflag = 0;
 	char *iarg = NULL;
@@ -107,16 +108,15 @@ int main(int argc, char *argv[])
 	while ((c = getopt_long(argc, argv, "hj:l:p:s:i:g:r",
 				long_options, &option_index)) != -1) {
 			switch (c) {
-			case 'h': /* local host loopback */
+			case 'h':
 				display_help(argv[0], 0);
 				break;
-			case 'l': /* network line loopback */
+			case 'l': /* loopback */
 				larg = optarg;
 				doloopback = 1;
 				break;
 			case 's': /* specify a span */
 				span = atoi(optarg);
-				sflag = 1;
 				break;
 			case 'i': /* insert an error */
 				iarg = optarg;
@@ -140,7 +140,7 @@ int main(int argc, char *argv[])
 	if (!(doloopback || iflag || gflag || rflag)) {
 		s.spanno = span;
 		res = ioctl(ctl, DAHDI_SPANSTAT, &s);
-		if (res)
+		if (res || ((__u32)-1 == s.fecount))
 			printf("Error counters not supported by the driver"\
 					" for this span\n");
 		printf("Span %d:\n", span);
